// Adobe CS3-CS6 Color Library
// By KaZuhiro FuRuhata
// 2013.3.22

// カラーを変換するするメソッド
var $$ = {};
$$.color = $$.color || {
	// ------------------------------------------------------------------------------------
	// RGBカラーからHSBカラーに変換
	//  (R:0~255, G:0〜255, B:0〜255, h:0〜360, s:0〜1, B:0〜1)
	// ------------------------------------------------------------------------------------
	RGBtoHSB : function (r, g, b){
		var h = s = v = 0;
		if ( r >= g)   cmax = r; else cmax = g;
		if ( b > cmax) cmax = b;
		if ( r <= g)   cmin = r; else cmin = g;
		if ( b < cmin) cmin = b;
		v = cmax;
		var c = cmax - cmin;
		if (cmax == 0) s = 0; else s = c/cmax;
		if (s != 0){
			if (r == cmax){ h = (g - b)/c;
			}else{
				if (g == cmax){ h = 2 + (b - r)/c;
				}else{
					if (b == cmax) h = 4 + ( r - g)/c;
				}
			}
			h = h * 60;
			if (h < 0) h = h + 360;
		}
		return { H:h, S:s, B:v/255 }
	},
	// ------------------------------------------------------------------------------------
	// HSBカラーからRGBカラーに変換
	//  (R:0~255, G:0〜255, B:0〜255, h:0〜360, s:0〜1, B:0〜1)
	// ------------------------------------------------------------------------------------
	HSBtoRGB : function (h, s, v){
		var r = g = b = 0;
		if (s < 0) s = 0;
		if (s > 1) s = 1;
		if (v < 0) v = 0;
		if (v > 1) v = 1;
		h = h % 360;
		if (h < 0) h = h + 360;
		h = h / 60;
		i = Math.floor(h);
		var f = h - i;
		p1 = v * (1 - s);
		p2 = v * (1 - s*f);
		p3 = v * (1 - s*(1 - f));
		if (i == 0) { r = v; g = p3; b = p1; }
		if (i == 1) { r = p2;g = v;  b = p1; }
		if (i == 2) { r = p1;g = v;  b = p3; }
		if (i == 3) { r = p1;g = p2; b = v;  }
		if (i == 4) { r = p3;g = p1; b = v;  }
		if (i == 5) { r = v; g = p1; b = p2; }
		return { R:r*255, G:g*255, B:b*255 }
	},
	// ------------------------------------------------------------------------------------
	// RGBカラーからGrayスケールに変換
	//  (R:0~255, G:0〜255, B:0〜255, g:0〜1)
	// ------------------------------------------------------------------------------------
	RGBtoGray : function (r, g, b){
		r = r / 255;
		g = g / 255;
		b = b / 255;
		return { g : r*0.299+g*0.587+b*0.114 };
	},
	// ------------------------------------------------------------------------------------
	// GrayスケールからRGBカラーに変換
	//  (R:0~255, G:0〜255, B:0〜255, g:0〜1)
	// ------------------------------------------------------------------------------------
	GraytoRGB : function (g){
		return { R:g*255, G:g*255, B:g*255 }
	},
	// ------------------------------------------------------------------------------------
	// CIE XYZカラーからsRGBカラーに変換
	//  (R:0~255, G:0〜255, B:0〜255, X:０〜1, Y : 0〜1, Z : 0〜1 )
	// ------------------------------------------------------------------------------------
	XYZtoRGB : function (X, Y, Z){
		var r = 3.240479 * X - 1.53715 * Y - 0.498535 * Z;
		var g = -0.969256 * X + 1.875991 * Y + 0.041556 * Z;
		var b= 0.055648 * X - 0.204043 * Y + 1.057311 * Z;
		return { R:r*255, G:g*255, B:b*255 }
	},
	// ------------------------------------------------------------------------------------
	// sRGBカラーからCIE XYZカラーに変換
	//  (R:0~255, G:0〜255, B:0〜255, X:０〜1, Y : 0〜1, Z : 0〜1 )
	// ------------------------------------------------------------------------------------
	RGBtoXYZ : function (r, g, b){
		r = r / 255;
		g = g / 255;
		b = b /255;
		var x = 0.412453 * r + 0.35758 * g + 0.180423 * b;
		var y = 0.212671 * r + 0.71516 * g + 0.072169 * b;
		var z = 0.019334 * r + 0.119193 * g + 0.950227 * b;
		return { X : x, Y : y, Z : z }
	}
}